Behaviours: gen_server.
A reporter that sends the spans to an jaeger agent using UDP.
To start a reporter process, please use jaeger_passage_reporter:start/1 or jaeger_passage_reporter:start/2.
%% Starts `example_reporter'
{ok, Reporter} = jaeger_passage_reporter:start(example_reporter, [{protocol, udp}]).
[example_reporter] = jaeger_passage_reporter:which_reporters().
%% Registers `example_tracer'
Context = jaeger_passage_span_context.
Sampler = passage_sampler_all:new().
ok = passage_tracer_registry:register(example_tracer, Context, Sampler, Reporter).
%% Starts and finishes a span
Span = passage:start_span(example, [{tracer, example_tracer}]).
passage:finish_span(Span). % The span will send to the jaeger agent on the localhost
start_option() = {default_service_name, atom()} | {process_tags, passage:tags()} | {thrift_format, thrift_protocol:format()} | {agent_host, inet:hostname()} | {agent_port, inet:port_number()}
location.application tag, the value is used as the service name instead of this. The default value is ReporterId.#{}.compact."127.0.0.1".compact and binary are 6831 and 6832 respectively.start_options() = [start_option()]
Options for jaeger_passage_reporter:start/2.
Generated by EDoc, Jan 23 2020, 22:32:01.